# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: brainiac.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='brainiac.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0e\x62rainiac.proto\x1a\x1cgoogle/protobuf/struct.proto\".\n\x08UserData\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"*\n\x0bProjectData\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"4\n\x06Status\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x15\n\rstatus_reason\x18\x02 \x01(\t\"\x9f\x01\n\x11ThirdPartyRequest\x12\x19\n\x06\x63lient\x18\x01 \x01(\x0b\x32\t.UserData\x12\x10\n\x08\x66unction\x18\x02 \x01(\x0c\x12\x1e\n\x08projects\x18\x03 \x03(\x0b\x32\x0c.ProjectData\x12\x16\n\x0e\x66orce_download\x18\x04 \x01(\x08\x12%\n\x04\x62ody\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"T\n\x12ThirdPartyResponse\x12\x17\n\x06status\x18\x01 \x01(\x0b\x32\x07.Status\x12%\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xa1\x01\n\x0f\x42rainiacRequest\x12\x19\n\x06\x63lient\x18\x01 \x01(\x0b\x32\t.UserData\x12\x1d\n\x07project\x18\x02 \x01(\x0b\x32\x0c.ProjectData\x12\x15\n\rfunction_name\x18\x03 \x01(\t\x12\x16\n\x0e\x66orce_download\x18\x04 \x01(\x08\x12%\n\x04\x62ody\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"R\n\x10\x42rainiacResponse\x12\x17\n\x06status\x18\x01 \x01(\x0b\x32\x07.Status\x12%\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct2\xb7\x01\n\x06\x45ngine\x12\x34\n\x0brunFunction\x12\x10.BrainiacRequest\x1a\x11.BrainiacResponse\"\x00\x12?\n\x12thirdPartyFunction\x12\x12.ThirdPartyRequest\x1a\x13.ThirdPartyResponse\"\x00\x12\x36\n\rlistFunctions\x12\x10.BrainiacRequest\x1a\x11.BrainiacResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_USERDATA = _descriptor.Descriptor(
  name='UserData',
  full_name='UserData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='UserData.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='UserData.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=94,
)


_PROJECTDATA = _descriptor.Descriptor(
  name='ProjectData',
  full_name='ProjectData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='ProjectData.owner', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='ProjectData.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=138,
)


_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code', full_name='Status.status_code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status_reason', full_name='Status.status_reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=192,
)


_THIRDPARTYREQUEST = _descriptor.Descriptor(
  name='ThirdPartyRequest',
  full_name='ThirdPartyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='ThirdPartyRequest.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function', full_name='ThirdPartyRequest.function', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='projects', full_name='ThirdPartyRequest.projects', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_download', full_name='ThirdPartyRequest.force_download', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='ThirdPartyRequest.body', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=354,
)


_THIRDPARTYRESPONSE = _descriptor.Descriptor(
  name='ThirdPartyResponse',
  full_name='ThirdPartyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ThirdPartyResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='ThirdPartyResponse.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=440,
)


_BRAINIACREQUEST = _descriptor.Descriptor(
  name='BrainiacRequest',
  full_name='BrainiacRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='BrainiacRequest.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project', full_name='BrainiacRequest.project', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_name', full_name='BrainiacRequest.function_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_download', full_name='BrainiacRequest.force_download', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='BrainiacRequest.body', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=604,
)


_BRAINIACRESPONSE = _descriptor.Descriptor(
  name='BrainiacResponse',
  full_name='BrainiacResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='BrainiacResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='BrainiacResponse.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=606,
  serialized_end=688,
)

_THIRDPARTYREQUEST.fields_by_name['client'].message_type = _USERDATA
_THIRDPARTYREQUEST.fields_by_name['projects'].message_type = _PROJECTDATA
_THIRDPARTYREQUEST.fields_by_name['body'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_THIRDPARTYRESPONSE.fields_by_name['status'].message_type = _STATUS
_THIRDPARTYRESPONSE.fields_by_name['body'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_BRAINIACREQUEST.fields_by_name['client'].message_type = _USERDATA
_BRAINIACREQUEST.fields_by_name['project'].message_type = _PROJECTDATA
_BRAINIACREQUEST.fields_by_name['body'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_BRAINIACRESPONSE.fields_by_name['status'].message_type = _STATUS
_BRAINIACRESPONSE.fields_by_name['body'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['UserData'] = _USERDATA
DESCRIPTOR.message_types_by_name['ProjectData'] = _PROJECTDATA
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.message_types_by_name['ThirdPartyRequest'] = _THIRDPARTYREQUEST
DESCRIPTOR.message_types_by_name['ThirdPartyResponse'] = _THIRDPARTYRESPONSE
DESCRIPTOR.message_types_by_name['BrainiacRequest'] = _BRAINIACREQUEST
DESCRIPTOR.message_types_by_name['BrainiacResponse'] = _BRAINIACRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserData = _reflection.GeneratedProtocolMessageType('UserData', (_message.Message,), dict(
  DESCRIPTOR = _USERDATA,
  __module__ = 'brainiac_pb2'
  # @@protoc_insertion_point(class_scope:UserData)
  ))
_sym_db.RegisterMessage(UserData)

ProjectData = _reflection.GeneratedProtocolMessageType('ProjectData', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTDATA,
  __module__ = 'brainiac_pb2'
  # @@protoc_insertion_point(class_scope:ProjectData)
  ))
_sym_db.RegisterMessage(ProjectData)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
  DESCRIPTOR = _STATUS,
  __module__ = 'brainiac_pb2'
  # @@protoc_insertion_point(class_scope:Status)
  ))
_sym_db.RegisterMessage(Status)

ThirdPartyRequest = _reflection.GeneratedProtocolMessageType('ThirdPartyRequest', (_message.Message,), dict(
  DESCRIPTOR = _THIRDPARTYREQUEST,
  __module__ = 'brainiac_pb2'
  # @@protoc_insertion_point(class_scope:ThirdPartyRequest)
  ))
_sym_db.RegisterMessage(ThirdPartyRequest)

ThirdPartyResponse = _reflection.GeneratedProtocolMessageType('ThirdPartyResponse', (_message.Message,), dict(
  DESCRIPTOR = _THIRDPARTYRESPONSE,
  __module__ = 'brainiac_pb2'
  # @@protoc_insertion_point(class_scope:ThirdPartyResponse)
  ))
_sym_db.RegisterMessage(ThirdPartyResponse)

BrainiacRequest = _reflection.GeneratedProtocolMessageType('BrainiacRequest', (_message.Message,), dict(
  DESCRIPTOR = _BRAINIACREQUEST,
  __module__ = 'brainiac_pb2'
  # @@protoc_insertion_point(class_scope:BrainiacRequest)
  ))
_sym_db.RegisterMessage(BrainiacRequest)

BrainiacResponse = _reflection.GeneratedProtocolMessageType('BrainiacResponse', (_message.Message,), dict(
  DESCRIPTOR = _BRAINIACRESPONSE,
  __module__ = 'brainiac_pb2'
  # @@protoc_insertion_point(class_scope:BrainiacResponse)
  ))
_sym_db.RegisterMessage(BrainiacResponse)



_ENGINE = _descriptor.ServiceDescriptor(
  name='Engine',
  full_name='Engine',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=691,
  serialized_end=874,
  methods=[
  _descriptor.MethodDescriptor(
    name='runFunction',
    full_name='Engine.runFunction',
    index=0,
    containing_service=None,
    input_type=_BRAINIACREQUEST,
    output_type=_BRAINIACRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='thirdPartyFunction',
    full_name='Engine.thirdPartyFunction',
    index=1,
    containing_service=None,
    input_type=_THIRDPARTYREQUEST,
    output_type=_THIRDPARTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='listFunctions',
    full_name='Engine.listFunctions',
    index=2,
    containing_service=None,
    input_type=_BRAINIACREQUEST,
    output_type=_BRAINIACRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENGINE)

DESCRIPTOR.services_by_name['Engine'] = _ENGINE

# @@protoc_insertion_point(module_scope)
