PICKLE_PROTOCOL = 4
BRAINIAC_CLIENT_USERNAME = "BRAINIAC_CLIENT_USERNAME"
BRAINIAC_CLIENT_PASSWORD = "BRAINIAC_CLIENT_PASSWORD"
DEFAULT_PORT = 5000
BRAINIAC_ENGINE_URL = "https://brainiac-engine.herokuapp.com/"
