# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import brainiac_client.protos.brainiac_pb2 as brainiac__pb2


class EngineStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.runFunction = channel.unary_unary(
        '/Engine/runFunction',
        request_serializer=brainiac__pb2.BrainiacRequest.SerializeToString,
        response_deserializer=brainiac__pb2.BrainiacResponse.FromString,
        )
    self.thirdPartyFunction = channel.unary_unary(
        '/Engine/thirdPartyFunction',
        request_serializer=brainiac__pb2.ThirdPartyRequest.SerializeToString,
        response_deserializer=brainiac__pb2.ThirdPartyResponse.FromString,
        )
    self.listFunctions = channel.unary_unary(
        '/Engine/listFunctions',
        request_serializer=brainiac__pb2.BrainiacRequest.SerializeToString,
        response_deserializer=brainiac__pb2.BrainiacResponse.FromString,
        )


class EngineServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def runFunction(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def thirdPartyFunction(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def listFunctions(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_EngineServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'runFunction': grpc.unary_unary_rpc_method_handler(
          servicer.runFunction,
          request_deserializer=brainiac__pb2.BrainiacRequest.FromString,
          response_serializer=brainiac__pb2.BrainiacResponse.SerializeToString,
      ),
      'thirdPartyFunction': grpc.unary_unary_rpc_method_handler(
          servicer.thirdPartyFunction,
          request_deserializer=brainiac__pb2.ThirdPartyRequest.FromString,
          response_serializer=brainiac__pb2.ThirdPartyResponse.SerializeToString,
      ),
      'listFunctions': grpc.unary_unary_rpc_method_handler(
          servicer.listFunctions,
          request_deserializer=brainiac__pb2.BrainiacRequest.FromString,
          response_serializer=brainiac__pb2.BrainiacResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'Engine', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
